@@ -141,7 +141,7 @@ def _dot(v1, v2):
 @cython.cfunc
 @cython.inline
 @cython.returns(cython.double)
-@cython.locals(x=cython.complex)
+@cython.locals(x=cython.double)
 def _intSecAtan(x):
     # In : sympy.integrate(sp.sec(sp.atan(x)))
     # Out: x*sqrt(x**2 + 1)/2 + asinh(x)/2
@@ -1370,6 +1370,11 @@ def _curve_curve_intersections_t(
     return unique_values
 
 
+def _is_linelike(segment):
+    maybeline = _alignment_transformation(segment).transformPoints(segment)
+    return all(math.isclose(p[1], 0.0) for p in maybeline)
+
+
 def curveCurveIntersections(curve1, curve2):
     """Finds intersections between a curve and a curve.
 
@@ -1391,6 +1396,17 @@ def curveCurveIntersections(curve1, curve2):
         >>> intersections[0].pt
         (81.7831487395506, 109.88904552375288)
     """
+    if _is_linelike(curve1):
+        line1 = curve1[0], curve1[-1]
+        if _is_linelike(curve2):
+            line2 = curve2[0], curve2[-1]
+            return lineLineIntersections(*line1, *line2)
+        else:
+            return curveLineIntersections(curve2, line1)
+    elif _is_linelike(curve2):
+        line2 = curve2[0], curve2[-1]
+        return curveLineIntersections(curve1, line2)
+
     intersection_ts = _curve_curve_intersections_t(curve1, curve2)
     return [
         Intersection(pt=segmentPointAtT(curve1, ts[0]), t1=ts[0], t2=ts[1])
